jan: thuban/Extensions/wms __init__.py,1.1,1.2

cvs@intevation.de cvs at intevation.de
Sat Nov 20 22:26:08 CET 2004


Author: jan

Update of /thubanrepository/thuban/Extensions/wms
In directory doto:/tmp/cvs-serv9135

Modified Files:
	__init__.py 
Log Message:
Added registry entry and the importing
of the actual wms module. Included a test for the required PyOGCLib.


Index: __init__.py
===================================================================
RCS file: /thubanrepository/thuban/Extensions/wms/__init__.py,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- __init__.py	12 Nov 2003 08:14:23 -0000	1.1
+++ __init__.py	20 Nov 2004 21:26:06 -0000	1.2
@@ -1,6 +1,28 @@
-# Copyright (c) 2003 by Intevation GmbH
+# Copyright (c) 2003, 2004 by Intevation GmbH
 # Authors:
 # Jan-Oliver Wagner <jan at intevation.de>
 #
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with Thuban for details.
+
+# first try out whether we can import the required module
+# of the PyOGCLib.
+ok = True
+try:
+    import ogclib.WMSClient
+except:
+    print "Problems with PyOGCLib (not installed?)"
+    ok = False
+
+if ok:
+    import wms
+
+    from Thuban.UI.extensionregistry import ExtensionDesc, ext_registry
+    from Thuban import _
+
+    ext_registry.add(ExtensionDesc(
+        name = 'WMS',
+        version = '0.2.0',
+        authors= [ 'Jan-Oliver Wagner', 'Martin Schulze' ],
+        copyright = '2003, 2004 Intevation GmbH',
+        desc = _("Provide layers via OGC WMS.")))
@@ -1,6 +1,28 @@
 # Authors:
-# Jan-Oliver Wagner <jan at intevation.de>
+# Jan-Oliver Wagner <jan at intevation.de> (2003, 2004)
 #
 # This program is free software under the GPL (>=v2)





More information about the Thuban-devel mailing list

This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)